.. -*- rst -*- -*- restructuredtext -*-
.. This file should be written using restructured text conventions

Salem
=====

.. image:: https://badge.fury.io/py/salem.svg
    :target: https://badge.fury.io/py/salem
.. image:: https://anaconda.org/conda-forge/salem/badges/version.svg
   :target: https://anaconda.org/conda-forge/salem/
.. image:: https://travis-ci.com/fmaussion/salem.svg?branch=master
    :target: https://travis-ci.com/fmaussion/salem
.. image:: https://coveralls.io/repos/fmaussion/salem/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/fmaussion/salem?branch=master
.. image:: https://readthedocs.org/projects/salem/badge/?version=stable
    :target: http://salem.readthedocs.io/en/stable/?badge=stable
.. image:: https://zenodo.org/badge/42607422.svg
    :target: https://zenodo.org/badge/latestdoi/42607422


Salem is a small library to do geoscientific data
processing and plotting. It extends `xarray`_ to add geolocalised
subsetting, masking, and plotting operations to xarray's `DataArray`_ and
`DataSet`_ structures.

.. _xarray: http://xarray.pydata.org/en/stable/
.. _DataArray: http://xarray.pydata.org/en/stable/data-structures.html#dataarray
.. _DataSet: http://xarray.pydata.org/en/stable/data-structures.html#dataset

Documentation
-------------

A draft of documentation is hosted on ReadTheDocs: http://salem.readthedocs.io

License
-------

Salem is available under the open source `3-clause BSD license`_.

.. _3-clause BSD license: https://en.wikipedia.org/wiki/BSD_licenses

About
-----

:Status:
    Beta - in development

:License:
    3-clause BSD

:Contact:
    `Fabien Maussion <http://fabienmaussion.info/>`_
